package es.verdnatura.presentation.view.feature.packaging.fragment

import android.graphics.drawable.Drawable
import android.os.Build
import android.text.InputType
import android.view.View
import android.widget.ImageView
import androidx.recyclerview.widget.LinearLayoutManager
import es.verdnatura.R
import es.verdnatura.databinding.FragmentPackagingCountBinding
import es.verdnatura.presentation.base.BaseFragment
import es.verdnatura.presentation.common.*
import es.verdnatura.presentation.view.component.CustomDialog
import es.verdnatura.presentation.view.component.CustomDialogInput
import es.verdnatura.presentation.view.feature.packaging.adapter.ItemSupplierAdapter
import es.verdnatura.presentation.view.feature.packaging.fragment.PackagingViewModel.PackagingViewModel
import es.verdnatura.presentation.view.feature.packaging.model.ItemSupplier
import es.verdnatura.presentation.view.feature.pasillero.model.PasillerosItemVO


@Suppress("UNUSED_ANONYMOUS_PARAMETER")
class PackagingCountFragment(
    var entryPoint: String = ""

) : BaseFragment<FragmentPackagingCountBinding, PackagingViewModel>(
    PackagingViewModel::class
) {

    private var adapteritemsupplier: ItemSupplierAdapter? = null
    private lateinit var customDialogInput: CustomDialogInput
    private var listItemSupplier: MutableList<ItemSupplier> = ArrayList()
    private lateinit var customDialog: CustomDialog
    private var layoutManager: LinearLayoutManager? = null

    companion object {
        fun newInstance(entryPoint: String) = PackagingCountFragment(entryPoint)
    }

    override fun getLayoutId(): Int = R.layout.fragment_packaging_count


    override fun init() {
       // binding.splashProgress.visibility = View.VISIBLE
        viewModel.getItemsPackaging(
            mobileApplication.dataStoreApp.readDataStoreKey("SUPPLIERID"), mobileApplication.dataStoreApp.readDataStoreKey("ENTRYID")
        )
        customDialogInput = CustomDialogInput(requireContext())
        customDialog = CustomDialog(requireContext())
        ma.hideBottomNavigation(View.GONE)
        setToolBar()
        setEvents()
        super.init()
    }

    private fun setToolBar() {

        binding.mainToolbar.toolbarTitle.text =
            "${mobileApplication.dataStoreApp.readDataStoreKey<String>("ENTRYTYPE")}:" +
                    " ${mobileApplication.dataStoreApp.readDataStoreKey<String>("SUPPLIERNAME")}"

        val listIcons: ArrayList<ImageView> = ArrayList()
        val iconNext = ImageView(context)
        iconNext.setImageResource(R.drawable.ic_chevron_right_black_24dp)
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            iconNext.tooltipText = getString(R.string.entryNextObsers)
        }
        listIcons.add(iconNext)
        binding.mainToolbar.toolbarIcons.adapter =
            ToolBarAdapterTooltip(listIcons, object : OnOptionsSelectedListener {
                override fun onOptionsItemSelected(item: Drawable) {
                    when (item) {
                        iconNext.drawable -> {
                            ma.onPasillerosItemClickListener(
                                PasillerosItemVO(title = getString(R.string.titlePackagingObs)),
                                getString(R.string.titlePackagingObs)
                            )
                        }

                    }

                }

            })
        binding.mainToolbar.toolbarIcons.layoutManager =
            LinearLayoutManager(requireContext(), LinearLayoutManager.HORIZONTAL, false)

    }

    private fun setEvents() {

        binding.mainToolbar.backButton.setOnClickListener {
            requireActivity().onBackPressed()
        }

    }


    override fun observeViewModel() {
        with(viewModel) {

            entryAdd.observe(viewLifecycleOwner) {

                if (it.isError) {
                    //binding.splashProgress.visibility = View.INVISIBLE
                    ma.messageWithSound(it.errorMessage, true, true)

                } else {
                    ma.messageWithSound(it.errorMessage, false, true)
                    //binding.splashProgress.visibility = View.VISIBLE
                    viewModel.getItemsPackaging(
                        mobileApplication.dataStoreApp.readDataStoreKey("SUPPLIERID"), mobileApplication.dataStoreApp.readDataStoreKey("ENTRYID"))
                }
            }

            itemSupplierList.observe(viewLifecycleOwner) {
                //binding.splashProgress.visibility = View.GONE
                adapteritemsupplier =
                    ItemSupplierAdapter(it.list, object : OnImageUpdateClickListener {

                        override fun OnImageUpdateClickListener(item: Any) {
                            showCustomDialog("quantity", item as ItemSupplier)


                        }

                    }, object : OnImageTrashClickListener {
                        override fun OnImageTrashClickListener(item: Any) {
                            showCustomDialog("delete", item as ItemSupplier)
                        }

                    }, object : OnEditSubQuantityListener {
                        override fun OnEditSubQuantityListener(item: Any, text: String) {
                            hideKeyboard()
                        }
                    })

                binding.itemsupplierRecyclerview.adapter = adapteritemsupplier
                layoutManager =
                    LinearLayoutManager(requireContext(), LinearLayoutManager.VERTICAL, false)
                binding.itemsupplierRecyclerview.layoutManager = layoutManager

            }

        }
    }

    private fun showCustomDialog(action: String, item: ItemSupplier) {

        when (action) {
            "quantity" -> {
                customDialogInput.getEditText().setRawInputType(InputType.TYPE_CLASS_NUMBER)
                customDialogInput.setTitle(getString(R.string.quantityReviewed))
                    .setDescription(getString(R.string.Indicanuevacantidad))
                    .setOkButton(getString(R.string.accept)) {
                        if (customDialogInput.getValue().isNotEmpty()) {
                            requireActivity().hideKeyboard()
                        }

                        //binding.splashProgress.visibility = View.VISIBLE
                        viewModel.entry_addFromBuy(
                            mobileApplication.dataStoreApp.readDataStoreKey<Int>("ENTRYID"), item = item.id!!.toInt(),
                            (if (mobileApplication.dataStoreApp.readDataStoreKey<String>("ENTRYTYPE") == "Rec") {
                                (item.printedStickers.plus(customDialogInput.getValue().toInt()))
                            } else {
                                item.printedStickers.plus(customDialogInput.getValue().toInt())
                            }) as Number
                        )
                        customDialog.cancel()
                        customDialogInput.dismiss()
                        customDialogInput.setValue("")
                    }.setKoButton(getString(R.string.cancel)) {
                        customDialog.cancel()
                        customDialogInput.dismiss()
                    }.setValue("")
                    .show()



                customDialogInput.currentFocus
                customDialogInput.setFocusText()
            }
            "delete" -> {
                customDialog.setTitle(getString(R.string.deleteEntryReviewed))
                    .setDescription(getString(R.string.sure))
                    .setOkButton(
                        getString(
                            R.string.delete
                        )

                    ) {
                        customDialog.cancel()
                        customDialog.dismiss()
                        //binding.splashProgress.visibility = View.VISIBLE
                        viewModel.entry_addFromBuy(
                            mobileApplication.dataStoreApp.readDataStoreKey("ENTRYID"), item = item.id!!.toInt(),
                            0
                        )
                    }

                    .setKoButton(getString(R.string.cancel)) {
                        customDialog.cancel()
                        customDialog.dismiss()


                    }
                    .show()
            }

        }

    }

}



