package es.verdnatura.presentation.view.feature.packaging.fragment

import android.content.Context
import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import es.verdnatura.R
import es.verdnatura.databinding.FragmentPackagingBinding
import es.verdnatura.domain.notNull
import es.verdnatura.presentation.base.BaseFragment
import es.verdnatura.presentation.common.OnPasillerosItemClickListener
import es.verdnatura.presentation.common.convertToDateString
import es.verdnatura.presentation.view.component.CustomDialog
import es.verdnatura.presentation.view.feature.inventario.fragment.SearchSupplierModel
import es.verdnatura.presentation.view.feature.packaging.fragment.PackagingViewModel.PackagingViewModel
import es.verdnatura.presentation.view.feature.packaging.model.EntrySalix
import es.verdnatura.presentation.view.feature.packaging.model.Supplier
import es.verdnatura.presentation.view.feature.pasillero.model.PasillerosItemVO
import ir.mirrajabi.searchdialog.SimpleSearchDialogCompat
import kotlinx.coroutines.runBlocking

@Suppress("UNUSED_ANONYMOUS_PARAMETER")
class SupplierFragment(
    var entryPoint: String = ""

) : BaseFragment<FragmentPackagingBinding, PackagingViewModel>(
    PackagingViewModel::class
) {

    private var pasillerosItemClickListener: OnPasillerosItemClickListener? = null
    private var layoutManager: LinearLayoutManager? = null
    private var onBack = false
    private val suppliers = ArrayList<SearchSupplierModel>()
    private val entries = ArrayList<SearchSupplierModel>()
    private lateinit var customDialog: CustomDialog

    companion object {
        fun newInstance(entryPoint: String) = SupplierFragment(entryPoint)
    }

    override fun getLayoutId(): Int = R.layout.fragment_packaging

    override fun onAttach(context: Context) {
        if (context is OnPasillerosItemClickListener) pasillerosItemClickListener = context
        super.onAttach(context)
    }

    override fun onCreate(savedInstanceState: Bundle?) {

        viewModel.getSuppliers()

        val drawableId: Int =
            R.drawable.background_test // Reemplaza "mi_drawable" con el nombre de tu recurso Drawable

        /*  val uri: Uri = Uri.parse(
              ContentResolver.SCHEME_ANDROID_RESOURCE + "://" +
                      context!!.resources.getResourcePackageName(drawableId) + '/' +
                      context!!.resources.getResourceTypeName(drawableId) + '/' +
                      context!!.resources.getResourceEntryName(drawableId)
          )

          val rutaAbsoluta: String = uri.toString()*/

        /*
                 val file = File("/storage/emulated/0/Android/data/es.verdnatura.sfusion/files/Pictures/test.png")
                val filePart = MultipartBody.Part.createFormData(
                    "file",
                    file.name,
                    RequestBody.create(MediaType.parse("image/png"), file)
                )
                viewModel.entry_uploadPhotoSalix(
                    1,
                    1,
                    442,
                    21,
                    "1",
                    "Example description",
                    false,
                    file = filePart
                )*/
        // viewModel.entry_addFromBuy(8,1,100)
        super.onCreate(savedInstanceState)
    }

    override fun onPause() {
        onBack = true
        super.onPause()

    }

    override fun init() {

        binding.splashProgress.visibility = View.VISIBLE
        binding.filterSupplier.setOnClickListener {
            SimpleSearchDialogCompat(
                context,
                getString(R.string.suppliers),
                getString(R.string.escribirparteNombre),
                null,
                suppliers
            ) { baseSearchDialogCompat, nombre, position ->
                binding.filterSupplier.text = (nombre.getName())
                println("nombreSupplier"+nombre.getName())
                binding.radiobuttonTypePackaging.visibility = View.VISIBLE
                runBlocking {
                    mobileApplication.dataStoreApp.editDataStoreKey(
                        "SUPPLIERNAME",
                        nombre.getName()
                    )
                    mobileApplication.dataStoreApp.editDataStoreKey(
                        "SUPPLIERID",
                        nombre.getId().toInt()
                    )
                }
                viewModel.getEntries_fromSupplier(nombre.getId().toInt())
                baseSearchDialogCompat.dismiss()
            }.show()
        }
        customDialog = CustomDialog(requireContext())
        ma.hideBottomNavigation(View.GONE)
        setToolBar()
        setEvents()

        super.init()
    }

    private fun setToolBar() {
        binding.mainToolbar.toolbarTitle.text = entryPoint
    }

    private fun setEvents() {

        binding.mainToolbar.backButton.setOnClickListener {
            requireActivity().onBackPressed()
        }


        binding.radiobuttonTypePackaging.setOnCheckedChangeListener { buttonView, isChecked ->
            when (isChecked) {
                R.id.radioButtonRec -> {
                    runBlocking {
                        mobileApplication.dataStoreApp.editDataStoreKey("ENTRYTYPE", "Rec")
                    }
                }

                R.id.radioButtonDev -> {
                    runBlocking {
                        mobileApplication.dataStoreApp.editDataStoreKey("ENTRYTYPE", "Dev")
                    }
                }

            }
            binding.filterEntry.visibility = View.VISIBLE

        }
    }

    private fun setEntryDialog() {
        binding.filterEntry.setOnClickListener {
            SimpleSearchDialogCompat(
                context,
                getString(R.string.Entrada),
                getString(R.string.escribirparteNombre),
                null,
                entries
            ) { baseSearchDialogCompat, nombre, position ->
                binding.filterEntry.setText((nombre.getName()))
                binding.radiobuttonTypePackaging.visibility = View.VISIBLE

                if (nombre.getName() == getString(R.string.newEntry)) {
                    addEntry()
                } else {
                    runBlocking {
                        mobileApplication.dataStoreApp.editDataStoreKey(
                            "ENTRYID",
                            nombre.getId().toInt()
                        )
                    }
                    ma.onPasillerosItemClickListener(
                        PasillerosItemVO(title = getString(R.string.titlePackagingCount)),
                        getString(R.string.titlePackagingCount)
                    )
                }
                baseSearchDialogCompat.dismiss()
            }.show()
        }

    }

    override fun observeViewModel() {
        with(viewModel) {
            supplierList.observe(viewLifecycleOwner) {
                binding.splashProgress.visibility = View.GONE
                createSupplierList(it.list)
            }
            entryList.observe(viewLifecycleOwner) {
                binding.splashProgress.visibility = View.GONE
                createEntryList(it.list)
            }

            response.observe(viewLifecycleOwner) {
                if (it.isError) {
                    ma.messageWithSound(it.errorMessage, true, false)

                }
            }

            loadEntryAdd.observe(viewLifecycleOwner) { event ->
                event.getContentIfNotHandled().notNull {
                    binding.splashProgress.visibility = View.INVISIBLE
                    if (it.isError) {
                        ma.messageWithSound(it.errorMessage, true, false)

                    } else {
                        runBlocking {
                            mobileApplication.dataStoreApp.editDataStoreKey(
                                "ENTRYID",
                                it.id!!.toInt()
                            )
                        }

                        ma.onPasillerosItemClickListener(
                            PasillerosItemVO(title = getString(R.string.titlePackagingCount)),
                            it.id!!.toString()
                        )
                    }

                }
            }

            /*  entryAdd.observe(viewLifecycleOwner) {
                  if (it.isError) {
                      ma.messageWithSound(it.errorMessage, true, false)

                  } else {
                      saveDataInt("ENTRYID", it.id!!.toInt())
                      ma.onPasillerosItemClickListener(
                          PasillerosItemVO(title = getString(R.string.titlePackagingCount)),
                          it.id!!.toString()
                      )
                  }
              }*/

            entry.observe(viewLifecycleOwner) {
                binding.splashProgress.visibility = View.GONE
                if (it.isError) {
                    ma.messageWithSound(it.errorMessage, true, false)

                } else {
                    runBlocking {
                        mobileApplication.dataStoreApp.editDataStoreKey("ENTRYID", it.id!!.toInt())
                    }

                    ma.onPasillerosItemClickListener(
                        PasillerosItemVO(title = getString(R.string.titlePackagingCount)),
                        getString(R.string.titlePackagingCount)
                    )
                }
            }
        }
    }

    private fun createSupplierList(list: List<Supplier>) {
        suppliers.clear()
        list.forEach { supplier ->
            if (!supplier.isError) {
                try {
                    suppliers.add(SearchSupplierModel(supplier.name, supplier.id.toString()))
                } catch (e: Exception) {
                }
            }
        }
    }

    private fun createEntryList(list: List<EntrySalix>) {
        entries.clear()
        list.forEach { entry ->
            if (!entry.isError!!) {
                try {
                    entries.add(
                        SearchSupplierModel(
                            entry.id.toString() + "->" + convertToDateString(entry.created),
                            id = entry.id.toString()
                        )
                    )
                } catch (e: Exception) {
                }
            }
        }

        entries.add(SearchSupplierModel(getString(R.string.newEntry), ""))
        setEntryDialog()
    }

    private fun addEntry() {

        customDialog.setTitle(getString(R.string.createEntryDescrip))
            .setDescription(getString(R.string.sure))
            .setOkButton(
                getString(
                    R.string.accept
                )

            ) {
                customDialog.cancel()
                customDialog.dismiss()
                binding.splashProgress.visibility = View.VISIBLE
                viewModel.entry_addFromPackaging(
                    mobileApplication.dataStoreApp.readDataStoreKey("SUPPLIERID"),
                    mobileApplication.dataStoreApp.readDataStoreKey<String>("ENTRYTYPE") == "Rec"
                )

            }

            .setKoButton(getString(R.string.cancel)) {
                customDialog.cancel()
                customDialog.dismiss()

            }
            .show()
    }

}

